@@ -15,7 +15,7 @@ from qqbot.model.announce import (
     CreateAnnounceRequest,
     Announce,
     CreateChannelAnnounceRequest,
-    RecommendChannelRequest
+    RecommendChannelRequest,
 )
 from qqbot.model.api_permission import (
     APIPermission,
@@ -43,6 +43,7 @@ from qqbot.model.guild_role import (
     RoleUpdateFilter,
     RoleUpdateInfo,
 )
+from qqbot.model.interaction import InteractionData
 from qqbot.model.member import User, Member
 from qqbot.model.message import (
     MessageSendRequest,
@@ -50,6 +51,7 @@ from qqbot.model.message import (
     CreateDirectMessageRequest,
     DirectMessageGuild,
     MessagesPager,
+    MessageGet,
 )
 from qqbot.model.mute import MuteOption
 from qqbot.model.pins_message import PinsMessage
@@ -63,13 +65,14 @@ from qqbot.model.token import Token
 from qqbot.model.user import ReqOption
 
 
-def async_listen_events(t_token: Token, is_sandbox: bool, *handlers: Handler):
+def async_listen_events(t_token: Token, is_sandbox: bool, *handlers: Handler, ret_coro=False):
     """
     异步注册并监听频道相关事件
 
     :param t_token: Token对象
     :param handlers: 包含事件类型和事件回调的Handler对象，支持多个对象
     :param is_sandbox:是否沙盒环境，默认为False
+    :param ret_coro: 是否返回协程对象
     """
     # 通过api获取websocket链接
     ws_api = WebsocketAPI(t_token, is_sandbox)
@@ -77,8 +80,8 @@ def async_listen_events(t_token: Token, is_sandbox: bool, *handlers: Handler):
     # 新建和注册监听事件
     t_intent = register_handlers(handlers)
     # 实例一个session_manager
-    manager = SessionManager()
-    manager.start(ws_ap, t_token.bot_token(), t_intent)
+    manager = SessionManager(ret_coro=ret_coro)
+    return manager.start(ws_ap, t_token.bot_token(), t_intent)
 
 
 class AsyncAPIBase:
@@ -439,7 +442,7 @@ class AsyncChannelPermissionsAPI(AsyncAPIBase):
 class AsyncMessageAPI(AsyncAPIBase):
     """消息"""
 
-    async def get_message(self, channel_id: str, message_id: str) -> Message:
+    async def get_message(self, channel_id: str, message_id: str) -> MessageGet:
         """
         获取指定消息
 
@@ -451,7 +454,7 @@ class AsyncMessageAPI(AsyncAPIBase):
             channel_id=channel_id, message_id=message_id
         )
         response = await self.http_async.get(url)
-        return json.loads(response, object_hook=Message)
+        return json.loads(response, object_hook=MessageGet)
 
     async def get_messages(
         self, channel_id: str, pager: MessagesPager
@@ -500,7 +503,9 @@ class AsyncMessageAPI(AsyncAPIBase):
         response = await self.http_async.post(url, request_json)
         return json.loads(response, object_hook=Message)
 
-    async def recall_message(self, channel_id: str, message_id: str, hide_tip: bool = False):
+    async def recall_message(
+        self, channel_id: str, message_id: str, hide_tip: bool = False
+    ):
         """
         撤回消息
 
@@ -713,7 +718,9 @@ class AsyncAnnouncesAPI(AsyncAPIBase):
         :param guild_id: 频道ID
         :param request: RecommendChannelRequest 对象
         """
-        url = get_url(APIConstant.guildAnnounceURI, self.is_sandbox).format(guild_id=guild_id)
+        url = get_url(APIConstant.guildAnnounceURI, self.is_sandbox).format(
+            guild_id=guild_id
+        )
         request_json = JsonUtil.obj2json_serialize(request)
         response = await self.http_async.post(url, request_json)
         return json.loads(response, object_hook=Announce)
@@ -844,7 +851,9 @@ class AsyncScheduleAPI(AsyncAPIBase):
 class AsyncReactionAPI(AsyncAPIBase):
     """异步表情表态接口"""
 
-    async def put_reaction(self, channel_id: str, message_id: str, emo_type: int, emo_id: str):
+    async def put_reaction(
+        self, channel_id: str, message_id: str, emo_type: int, emo_id: str
+    ):
         """
         对一条消息进行表情表态
 
@@ -859,7 +868,9 @@ class AsyncReactionAPI(AsyncAPIBase):
         response = await self.http_async.put(url)
         return response == ""
 
-    async def delete_reaction(self, channel_id: str, message_id: str, emo_type: int, emo_id: str):
+    async def delete_reaction(
+        self, channel_id: str, message_id: str, emo_type: int, emo_id: str
+    ):
         """
         删除自己对消息的进行表情表态
 
@@ -914,8 +925,31 @@ class AsyncPinsAPI(AsyncAPIBase):
         """
         用于获取子频道内的所有精华消息
         成功后返回 PinsMessage 对象
+
         :param channel_id: 子频道ID
         """
-        url = get_url(APIConstant.getPinsURI, self.is_sandbox).format(channel_id=channel_id)
+        url = get_url(APIConstant.getPinsURI, self.is_sandbox).format(
+            channel_id=channel_id
+        )
         response = await self.http_async.get(url)
         return json.loads(response, object_hook=PinsMessage)
+
+
+class AsyncInteractionAPI(AsyncAPIBase):
+    """互动回调API"""
+
+    async def put_interaction(
+        self, interaction_id: str, interaction_data: InteractionData
+    ):
+        """
+        对 interaction_id 进行互动回调数据异步回复更新
+
+        :param interaction_id: 互动事件的ID
+        :param interaction_data: 互动事件数据体
+        """
+        url = get_url(APIConstant.interactionURI, self.is_sandbox).format(
+            interaction_id=interaction_id
+        )
+        request_json = JsonUtil.obj2json_serialize(interaction_data)
+        response = await self.http_async.put(url, request_json)
+        return response == ""
